@@ -1,15 +1,12 @@
 #!perl -w
 package version::vxs;
 
-use 5.005_03;
+use v5.10;
 use strict;
 
-use vars qw(@ISA $VERSION $CLASS );
-
-$VERSION = '0.76_06';
-$VERSION = eval $VERSION;
-
-$CLASS = 'version::vxs';
+our $VERSION = 0.99_25;
+our $CLASS = 'version::vxs';
+our @ISA;
 
 eval {
     require XSLoader;
